
/*******************************************************************************
Estimate Regressions
*******************************************************************************/




use "rct_bars_pval_data.dta", clear

label var t_tenure "Tenure"
label var t_agro "Agroforestry"
label var t_agroXtenure "Both"

tempfile estfile
cap postclose allest 
postfile allest b bu bl p str15 treat using `estfile'

reg havedoc l.havedoc  t_* , cluster(vilid)

lincom _cons
post allest (`r(estimate)') (.) (.) (.) ("Control")

foreach var of varlist t_* {
	testparm `var'
	local pval = r(p)
	
	lincom `var' + _cons
	
	local vlab: var label `var'
	post allest (`r(estimate)') (`r(ub)') (`r(lb)') (`pval') ("`vlab'")
}


postclose allest

/*******************************************************************************
Make Figures
*******************************************************************************/



/************************
Make dataset of outcomes
************************/


clear
use `estfile'




gen x 				= 50 + 100*(_n-1)

gen plab 			= "p=" + string(p,"%9.3f")
gen treatlabheight 	= 0

/************************
Make figure
************************/



#d;
twoway
	(bar b x, barw(90) )
	(rcap bu bl x, lc(maroon))
	(scatter bu x, mlab(plab) ms(i) mlabp(12) color(maroon) )
	(scatter treatlabheight x, mlab(treat) ms(i) mlabp(12) mlabcolor(white) )
	, xsize(6) ylabel(0(.25).75 ) ymtick(.05(.05).7) 
				yline(0, lc(black) ) 
				xscale(off) graphregion( color(white)) ytitle("Effect (95% CI)") 
				legend(off)
				
;
#d cr
